==> mobiusft-1.10.tar.xz: mobiusft-1.10/src/python/mobius/filesystem/func_get_filesystems.cc <==
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
// Mobius Forensic Toolkit
// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018 Eduardo Aguiar
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
// Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=

// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//! \brief  C++ API module wrapper
//! \author Eduardo Aguiar
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
#include <Python.h>
#include "filesystem_ext2.h"
#include "filesystem_hfs.h"
#include "filesystem_iso.h"
#include "filesystem_ntfs.h"
#include "filesystem_vfat.h"
#include "disk/disk.h"

// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//! \brief function get_filesystems
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
PyObject*
func_get_filesystems (PyObject *, PyObject *args)
{
  // parse arguments
  PyObject *arg_disk;

  if (!PyArg_ParseTuple (args, "O!", &disk_disk_t, &arg_disk))
    return nullptr;

  mobius::disk::disk *disk_p = ((disk_disk_o *) arg_disk)->obj;

  // create list
  PyObject *ret = PyList_New (0);

  if (ret == nullptr)
    return nullptr;

  // run C++ code
  std::vector <mobius::filesystem::filesystem> filesystems;

  try
    {
      filesystems = mobius::filesystem::get_filesystems (*disk_p);

      for (const auto& fs : filesystems)
        {
          PyObject *item = nullptr;

          // create filesystem object
          if (fs.get_type () == "ext2")
            {
              item = _PyObject_New (&filesystem_filesystem_ext2_t);
              ((filesystem_filesystem_ext2_o *) item)->obj = new mobius::filesystem::filesystem_ext2 (fs);
            }

          else if (fs.get_type () == "hfs")
            {
              item = _PyObject_New (&filesystem_filesystem_hfs_t);
              ((filesystem_filesystem_hfs_o *) item)->obj = new mobius::filesystem::filesystem_hfs (fs);
            }

          else if (fs.get_type () == "iso")
            {
              item = _PyObject_New (&filesystem_filesystem_iso_t);
              ((filesystem_filesystem_iso_o *) item)->obj = new mobius::filesystem::filesystem_iso (fs);
            }

          else if (fs.get_type () == "ntfs")
            {
              item = _PyObject_New (&filesystem_filesystem_ntfs_t);
              ((filesystem_filesystem_ntfs_o *) item)->obj = new mobius::filesystem::filesystem_ntfs (fs);
            }

          else if (fs.get_type () == "vfat")
            {
              item = _PyObject_New (&filesystem_filesystem_vfat_t);
              ((filesystem_filesystem_vfat_o *) item)->obj = new mobius::filesystem::filesystem_vfat (fs);
            }

          else
            {
              PyErr_SetString (PyExc_TypeError, "unknown filesystem type");
              Py_CLEAR (ret);
              return nullptr;
            }

          // append object to the list
          PyList_Append (ret, (PyObject *) item);
          Py_DECREF (item);
        }
    }
  catch (const std::runtime_error& e)
    {
      PyErr_SetString (PyExc_Exception, e.what ());
      Py_CLEAR (ret);
      ret = nullptr;
    }

  return ret;
}

==> mobiusft-1.16.tar.xz: mobiusft-1.16/src/python/mobius/filesystem/func_get_filesystems.cc <==
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
// Mobius Forensic Toolkit
// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019 Eduardo Aguiar
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
// Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=

// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//! \brief  C++ API module wrapper
//! \author Eduardo Aguiar
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
#include <pymobius.h>
#include "filesystem.h"
#include "disk/disk.h"

// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//! \brief function get_filesystems
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
PyObject*
func_get_filesystems (PyObject *, PyObject *args)
{
  // parse arguments
  PyObject *arg_disk;

  if (!PyArg_ParseTuple (args, "O!", &disk_disk_t, &arg_disk))
    return nullptr;

  mobius::disk::disk *disk_p = ((disk_disk_o *) arg_disk)->obj;

  // create list
  PyObject *ret = nullptr;

  try
    {
      auto filesystems = mobius::filesystem::get_filesystems (*disk_p);

      ret = PyList_from_cpp_container (
               filesystems,
               PyMobius_Filesystem_Filesystem_from_cpp
            );
    }
  catch (const std::exception& e)
    {
      PyErr_SetString (PyExc_Exception, e.what ());
    }

  return ret;
}
